#
# spec file for package perl-NetPacket
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-NetPacket
Version:        1.7.2
Release:        1.17
%define cpan_name NetPacket
Summary:        Assemble/disassemble network packets at the protocol level
License:        Artistic-2.0
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YA/YANICK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Socket) >= 1.87
BuildRequires:  perl(parent)
Requires:       perl(Socket) >= 1.87
Requires:       perl(parent)
Recommends:     perl(Net::Pcap)
Recommends:     perl(Net::PcapUtils)
%{perl_requires}

%description
'NetPacket' provides a base class for a cluster of modules related to
decoding and encoding of network protocols. Each 'NetPacket' descendent
module knows how to encode and decode packets for the network protocol it
implements. Consult the documentation for the module in question for
protocol-specific implementation.

Note that there is no inheritance in the 'NetPacket::' cluster of modules
other than each protocol module being a 'NetPacket'. This was seen to be
too restrictive as imposing inheritance relationships (for example between
the IP, UDP and TCP protocols) would make things like tunneling or other
unusual situations difficult.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTORS doap.xml README README.mkdn
%license LICENSE

%changelog
* Sun Jul 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.7.2
  see /usr/share/doc/packages/perl-NetPacket/Changes
  1.7.2 2019-07-20
    [ DOCUMENTATION ]
  - fix typos. (GH#14)
    [ STATISTICS ]
  - code churn: 7 files changed, 121 insertions(+), 42 deletions(-)
* Sun Jun  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.7.1
  see /usr/share/doc/packages/perl-NetPacket/Changes
  1.7.1 2019-06-08
    [ BUG FIXES ]
  - fixes inverted ethernet ports (reported by sanyacomua)
    [ STATISTICS ]
  - code churn: 4 files changed, 140 insertions(+), 130 deletions(-)
* Mon Dec 31 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.7.0
  see /usr/share/doc/packages/perl-NetPacket/Changes
  1.7.0 2018-12-30
    [ ENHANCEMENTS ]
  - Setup aliases at compile time (Nicolas R, GH#11)
  - add recommended Net::Pcap{,Utils} from README (Zak B. Elep, GH#12)
    [ NEW FEATURES ]
  - adds back basic support for IPv6. (Dan Book, GH#10)
    [ STATISTICS ]
  - code churn: 16 files changed, 1177 insertions(+), 48 deletions(-)
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.6.0
  see /usr/share/doc/packages/perl-NetPacket/Changes
  1.6.0 2015-03-13
  [ENHANCEMENTS]
  - Clean up inheritance code (Philip Prindeville).
  - Add a truckload of constants (Philip Prindeville).
  [STATISTICS]
  - code churn: 12 files changed, 343 insertions(+), 220 deletions(-)
  1.5.0 2014-06-15
  [ENHANCEMENTS]
  - Addition of NetPacket::IPX. (Daniel Collins)
  - NetPacket::Ethernet implements 'encode'. (RT#93928, Guido Hungerbuehler)
  [STATISTICS]
  - code churn: 7 files changed, 337 insertions(+), 13 deletions(-)
  1.4.4 2013-11-30
  [BUG FIXES]
  - NetPacket::USBMon: also handle big endian perl without quad type.
    (GH#5, Andreas Schwab)
  - Typo fix in comments. (GH#6, fschlich)
  [STATISTICS]
  - code churn: 3 files changed, 13 insertions(+), 4 deletions(-)
  1.4.3 2013-10-03
  [BUG FIXES]
  - Unpack data in LittleEndian format. (GH#4, k0da)
  [STATISTICS]
  - code churn: 3 files changed, 62 insertions(+), 27 deletions(-)
  1.4.2 2013-09-25
  [BUG FIXES]
  - Dist::Zilla::Plugin::Test::Compile was causing test to potentially hang
    on Windows. (reported by Karen Etheridge)
  [MISC]
  - Tidy up the changelog. (GH#3, Neil Bowers)
  [STATISTICS]
  - code churn: 2 files changed, 46 insertions(+), 20 deletions(-)
- obsoletes perl-NetPacket-backport.patch
- remove upstreamed perl-NetPacket-bigendian.patch
* Wed Oct  9 2013 schwab@suse.de
- Extend last change for 32-bit big endian
* Thu Oct  3 2013 dvaleev@suse.com
- USB is little endian, so we need to convert it on BigEndian
  platforms (perl-NetPacket-bigendian.patch)
  upstream commit fc0563f746c44387d77e70792628fe2a03628751
* Fri Sep  6 2013 Greg.Freemyer@gmail.com
- update to 1.4.1 2013-09-05
  [BUG FIXES]
  - Test was using Errno constant and failing on some platforms.
* Tue Aug 27 2013 Greg.Freemyer@gmail.com
- update to 1.4.0
  - Fixing NetPacked::UDP documentation. (RT#85361, Ben Magistro)
  - New NetPacket::USBMon. (GH#2, lkundrak)
  - 'parse_tcp_options()' method added to NetPacket::TCP (patch by Tom
  Linden) [RT#71320]
  [BUG FIXES]
  - Parse SACK option and fix TSecr parsing. (GH#1, Robin Lee)
  - Fix NetPacket::UDP's strip. (RT#85038, reported by Stan Schwertly)
  - Use of constant withotu parenthesis made test fail under 5.6.2.
* Sat Jul 30 2011 Greg.Freemyer@opensuse.org
- Update to 1.2.0
  [ENHANCEMENTS]
  - Add support for Ethernet VLAN (thanks to Kai Chan)
  [BUG FIXES]
  - Add a INSTALL file
* Tue Mar 22 2011 pascal.bleser@opensuse.org
- initial version (1.1.1)
